@@ -10,7 +10,7 @@
  */
 
 #define AFF_VERSION	1.1
-#define AFFLIB_VERSION  1.6.22
+#define AFFLIB_VERSION  1.6.28
 
 /* Figure out what kind of OS we are running on */
 
@@ -62,6 +62,16 @@ typedef long long  int64;
 #define UNIX
 #endif 
 
+#ifdef __CYGWIN__
+typedef unsigned long long uint64;
+typedef long long  int64;
+#define I64d "qd"
+#define I64u "qu"
+#define UNIX
+#endif
+
+
+/* WIN32 is defined by the NMAKE makefile for Visual C++ under Windows */
 #ifdef WIN32                            
 typedef unsigned _int64 uint64;		/* 64-bit types Types */
 typedef          _int64  int64;
@@ -71,6 +81,10 @@ int64   ftello(FILE *stream);	 /* Functions that Microsoft forgot */
 int     fseeko(FILE *stream,int64 offset,int whence);
 #endif
 
+
+/* If our types still aren't defined, assume that we are running
+ * on some kind of Unix with GCC.
+ */
 #ifndef I64d
 /* Assume some kind of Unix running GCC */
 typedef unsigned long long uint64;
