@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2005/09/02 23:34:02 $
+ * $Date: 2006/05/11 16:34:07 $
  * 
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved 
@@ -16,11 +16,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <errno.h>
+#include <string.h>
 
 #include "tsk_os.h"
 #include "disk_ide.h"
 #include "libauxtools.h"
-#include "error.h"
 
 void
 usage()
@@ -80,7 +81,9 @@ main(int argc, char **argv)
 
     fd = open(device, O_RDONLY);
     if (fd == -1) {
-	error("error opening device %s (%m)", device);
+	fprintf(stderr, "error opening device %s (%s)", device,
+		strerror(errno));
+	exit(1);
     }
 
     /* Get the two address values */
