@@ -2,7 +2,7 @@
 ** dcalc
 ** The Sleuth Kit 
 **
-** $Date: 2006/04/06 01:15:55 $
+** $Date: 2006/07/10 13:26:20 $
 **
 ** Calculates the corresponding block number between 'dls' and 'dd' images
 ** when given an 'dls' block number, it determines the block number it
@@ -38,16 +38,14 @@ usage()
 	"\t  -s: The given address is from a 'dls -s' (slack) image\n");
     fprintf(stderr,
 	"\t  -u: The given address is from a 'dls' (unallocated) image\n");
-    fprintf(stderr, "\t-i imgtype: The format of the image file\n");
+    fprintf(stderr,
+	"\t-f fstype: The file system type (use '-f list' for supported types)\n");
+    fprintf(stderr,
+	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
     fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
     fprintf(stderr, "\t-v: verbose output to stderr\n");
     fprintf(stderr, "\t-V: Print version\n");
-    fprintf(stderr, "\t-f fstype: The file system type\n");
-    fs_print_types(stderr);
-    fprintf(stderr, "Supported image format types:\n");
-    img_print_types(stderr);
-
 
     exit(1);
 }
@@ -90,10 +88,19 @@ main(int argc, char **argv)
 
 	case 'f':
 	    fstype = optarg;
+	    if (strcmp(fstype, "list") == 0) {
+		fs_print_types(stderr);
+		exit(1);
+	    }
 	    break;
 
 	case 'i':
 	    imgtype = optarg;
+	    if (strcmp(imgtype, "list") == 0) {
+		img_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 
 	case 'o':
