@@ -2,7 +2,7 @@
 ** dcat
 ** The  Sleuth Kit 
 **
-** $Date: 2006/05/08 17:56:51 $
+** $Date: 2006/07/10 13:26:20 $
 **
 ** Given an image , block number, and size, display the contents
 ** of the block to stdout.
@@ -35,23 +35,21 @@ usage()
 	progname);
     fprintf(stderr, "\t-a: displays in all ASCII \n");
     fprintf(stderr, "\t-h: displays in hexdump-like fashion\n");
-    fprintf(stderr, "\t-i imgtype: The format of the image file\n");
+    fprintf(stderr,
+	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
     fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
+    fprintf(stderr,
+	"\t-f fstype: File system type (use '-f list' for supported types)\n");
     fprintf(stderr,
 	"\t-s: display basic block stats such as unit size, fragments, etc.\n");
     fprintf(stderr, "\t-v: verbose output to stderr\n");
     fprintf(stderr, "\t-V: display version\n");
     fprintf(stderr, "\t-w: displays in web-like (html) fashion\n");
-    fprintf(stderr, "\t-f fstype: File system type\n");
     fprintf(stderr,
 	"\t-u usize: size of each data unit in image (for raw, dls, swap)\n");
     fprintf(stderr,
 	"\t[num] is the number of data units to display (default is 1)\n");
-    fs_print_types(stderr);
-    fprintf(stderr, "\t%s (Unallocated Space)\n", DLS_TYPE);
-    fprintf(stderr, "Supported image format types:\n");
-    img_print_types(stderr);
 
     exit(1);
 }
@@ -83,6 +81,12 @@ main(int argc, char **argv)
 	    fstype = optarg;
 	    if (strcmp(fstype, DLS_TYPE) == 0)
 		fstype = RAW_STR;
+	    if (strcmp(fstype, "list") == 0) {
+		fprintf(stderr, "\t%s (Unallocated Space)\n", DLS_TYPE);
+		fs_print_types(stderr);
+		exit(1);
+	    }
+
 
 	    break;
 	case 'h':
@@ -90,6 +94,11 @@ main(int argc, char **argv)
 	    break;
 	case 'i':
 	    imgtype = optarg;
+	    if (strcmp(imgtype, "list") == 0) {
+		img_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 	case 'o':
 	    if ((imgoff = parse_offset(optarg)) == -1) {
