@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit
 **
-** $Date: 2006/05/11 15:53:20 $
+** $Date: 2006/07/05 18:24:09 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -161,7 +161,7 @@ slack_inode_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 		fprintf(stderr,
 		    "slack_inode_act: error walking file: %" PRIuINUM,
 		    fs_inode->addr);
-	    tsk_errno = 0;
+	    tsk_error_reset();
 	}
     }
 
@@ -179,7 +179,7 @@ slack_inode_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 			fprintf(stderr,
 			    "slack_inode_act: error walking file: %"
 			    PRIuINUM, fs_inode->addr);
-		    tsk_errno = 0;
+		    tsk_error_reset();
 		}
 	    }
 
