@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2006/04/07 21:21:02 $
+** $Date: 2006/07/10 17:11:10 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -79,7 +79,7 @@ ext2fs_group_load(EXT2FS_INFO * ext2fs, EXT2_GRPNUM_T grp_num)
 	    tsk_errstr[0] = '\0';
 	}
 	snprintf(tsk_errstr2, TSK_ERRSTR_L,
-	    "ext2fs_group_load: Group descriptor %d at %"
+	    "ext2fs_group_load: Group descriptor %" PRI_EXT2GRP " at %"
 	    PRIuOFF, grp_num, offs);
 	return 1;
     }
@@ -164,7 +164,7 @@ ext2fs_bmap_load(EXT2FS_INFO * ext2fs, EXT2_GRPNUM_T grp_num)
 	    tsk_errstr[0] = '\0';
 	}
 	snprintf(tsk_errstr2, TSK_ERRSTR_L,
-	    "ext2fs_bmap_load: Bitmap group %d at %"
+	    "ext2fs_bmap_load: Bitmap group %" PRI_EXT2GRP " at %"
 	    PRIu32, grp_num, getu32(fs, ext2fs->grp_buf->bg_block_bitmap));
     }
 
@@ -229,7 +229,7 @@ ext2fs_imap_load(EXT2FS_INFO * ext2fs, EXT2_GRPNUM_T grp_num)
 	    tsk_errstr[0] = '\0';
 	}
 	snprintf(tsk_errstr2, TSK_ERRSTR_L,
-	    "ext2fs_imap_load: Inode bitmap %d at %"
+	    "ext2fs_imap_load: Inode bitmap %" PRI_EXT2GRP " at %"
 	    PRIu32, grp_num, getu32(fs, ext2fs->grp_buf->bg_inode_bitmap));
     }
 
@@ -910,7 +910,10 @@ ext2fs_file_walk_direct(FS_INFO * fs, DATA_BUF * buf[],
     read_count = (length < buf[0]->size ? length : buf[0]->size);
 
     if (addr > fs->last_block) {
-	tsk_errno = TSK_ERR_FS_INODE_INT;
+	if (flags & FS_FLAG_FILE_RECOVER)
+	    tsk_errno = TSK_ERR_FS_RECOVER;
+	else
+	    tsk_errno = TSK_ERR_FS_INODE_INT;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "ext2: Invalid direct address (too large): %"
 	    PRIuDADDR "", (DADDR_T) addr);
@@ -985,7 +988,10 @@ ext2fs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
 	    addr);
 
     if (addr > fs->last_block) {
-	tsk_errno = TSK_ERR_FS_INODE_INT;
+	if (flags & FS_FLAG_FILE_RECOVER)
+	    tsk_errno = TSK_ERR_FS_RECOVER;
+	else
+	    tsk_errno = TSK_ERR_FS_INODE_INT;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "ext2fs: Indirect block address too large: %"
 	    PRIuDADDR, (DADDR_T) addr);
@@ -1037,7 +1043,10 @@ ext2fs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
 	OFF_T prevcnt = todo_count;
 
 	if (getu32(fs, (uint8_t *) & iaddr[n]) > fs->last_block) {
-	    tsk_errno = TSK_ERR_FS_INODE_INT;
+	    if (flags & FS_FLAG_FILE_RECOVER)
+		tsk_errno = TSK_ERR_FS_RECOVER;
+	    else
+		tsk_errno = TSK_ERR_FS_INODE_INT;
 	    snprintf(tsk_errstr, TSK_ERRSTR_L,
 		"ext2fs: Address in indirect block too large: %"
 		PRIu32, getu32(fs, (uint8_t *) & iaddr[n]));
@@ -1070,7 +1079,8 @@ ext2fs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
  * flag values: FS_FLAG_FILE_NOSPARSE, FS_FLAG_FILE_AONLY, FS_FLAG_FILE_SLACK
  * FS_FLAG_FILE_META
  *
- * nothing special is done for FS_FLAG_FILE_RECOVER
+ * If FS_FLAG_FILE_RECOVER is set, then most error codes are set to
+ * _RECOVER.  No special recovery logic exists in this code. 
  *
  * The action will use the flags: FS_FLAG_DATA_CONT, FS_FLAG_DATA_META
  * -- @@@ Currently do not do _ALLOC and _UNALLOC
@@ -1250,7 +1260,7 @@ ext2fs_fsstat(FS_INFO * fs, FILE * hFile)
 	fprintf(hFile, "LITES\n");
 	break;
     default:
-	fprintf(hFile, "%x\n", getu32(fs, sb->s_creator_os));
+	fprintf(hFile, "%" PRIx32 "\n", getu32(fs, sb->s_creator_os));
 	break;
     }
 
@@ -1368,8 +1378,7 @@ ext2fs_fsstat(FS_INFO * fs, FILE * hFile)
 	    fsi = ext2fs_inode_lookup(fs, or_in);
 	    /* Ignore this error */
 	    if (!fsi) {
-		tsk_errno = 0;
-		tsk_errstr[0] = '\0';
+		tsk_error_reset();
 		break;
 	    }
 
@@ -1398,7 +1407,8 @@ ext2fs_fsstat(FS_INFO * fs, FILE * hFile)
     fprintf(hFile, "\nBLOCK GROUP INFORMATION\n");
     fprintf(hFile, "--------------------------------------------\n");
 
-    fprintf(hFile, "Number of Block Groups: %d\n", ext2fs->groups_count);
+    fprintf(hFile, "Number of Block Groups: %" PRI_EXT2GRP "\n",
+	ext2fs->groups_count);
 
     fprintf(hFile, "Inodes per group: %" PRIu32 "\n",
 	getu32(fs, sb->s_inodes_per_group));
@@ -1522,14 +1532,14 @@ ext2fs_fsstat(FS_INFO * fs, FILE * hFile)
 
 	/* The last group may not have a full number of blocks */
 	if (i != (ext2fs->groups_count - 1)) {
-	    fprintf(hFile, "  Free Inodes: %" PRIu16 " (%d%%)\n",
+	    fprintf(hFile, "  Free Inodes: %" PRIu16 " (%" PRIu32 "%%)\n",
 		getu16(fs, ext2fs->grp_buf->bg_free_inodes_count),
 		(100 *
 		    getu16(fs,
 			ext2fs->grp_buf->bg_free_inodes_count)) /
 		getu32(fs, sb->s_inodes_per_group));
 
-	    fprintf(hFile, "  Free Blocks: %" PRIu16 " (%d%%)\n",
+	    fprintf(hFile, "  Free Blocks: %" PRIu16 " (%" PRIu32 "%%)\n",
 		getu16(fs, ext2fs->grp_buf->bg_free_blocks_count),
 		(100 *
 		    getu16(fs,
@@ -1767,7 +1777,8 @@ ext2fs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 	/* Check the header */
 	ea_head = (ext2fs_ea_header *) buf;
 	if (getu32(fs, ea_head->magic) != EXT2_EA_MAGIC) {
-	    fprintf(hFile, "Incorrect extended attribute header: %x\n",
+	    fprintf(hFile,
+		"Incorrect extended attribute header: %" PRIx32 "\n",
 		getu32(fs, ea_head->magic));
 	}
 
@@ -1854,7 +1865,8 @@ ext2fs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 		    buf[getu16(fs, ea_entry->val_off)];
 
 		if (getu32(fs, acl_head->ver) != 1) {
-		    fprintf(hFile, "Invalid ACL Header Version: %d\n",
+		    fprintf(hFile,
+			"Invalid ACL Header Version: %" PRIu32 "\n",
 			getu32(fs, acl_head->ver));
 		    continue;
 		}
@@ -1902,13 +1914,13 @@ ext2fs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 
 
 		    case EXT2_PACL_TAG_GRP:
-			fprintf(hFile, "  gid: %d: %s\n",
+			fprintf(hFile, "  gid: %" PRIu32 ": %s\n",
 			    getu32(fs, acl_lo->id), perm);
 			len = sizeof(ext2fs_pos_acl_entry_lo);
 			break;
 
 		    case EXT2_PACL_TAG_USER:
-			fprintf(hFile, "  uid: %d: %s\n",
+			fprintf(hFile, "  uid: %" PRIu32 ": %s\n",
 			    getu32(fs, acl_lo->id), perm);
 
 			len = sizeof(ext2fs_pos_acl_entry_lo);
@@ -1982,8 +1994,7 @@ ext2fs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 		FS_FLAG_FILE_NOID), print_addr_act, (void *) &print)) {
 	fprintf(hFile, "\nError reading file:  ");
 	tsk_error_print(hFile);
-	tsk_errno = 0;
-	tsk_errstr[0] = '\0';
+	tsk_error_reset();
     }
     else {
 
