@@ -2,7 +2,7 @@
 ** ext2fs_dent
 ** The Sleuth Kit 
 **
-** $Date: 2006/04/13 16:05:25 $
+** $Date: 2006/07/05 18:24:09 $
 **
 ** File name layer support for an EXT2FS image
 **
@@ -305,9 +305,7 @@ ext2fs_dent_parse_block(EXT2FS_INFO * ext2fs, EXT2FS_DINFO * dinfo,
 		    tsk_error_print(stderr);
 		}
 
-		tsk_errno = 0;
-		tsk_errstr[0] = '\0';
-		tsk_errstr2[0] = '\0';
+		tsk_error_reset();
 	    }
 
 
