@@ -2,7 +2,7 @@
 ** fatfs
 ** The Sleuth Kit 
 **
-** $Date: 2006/05/11 15:53:20 $
+** $Date: 2006/07/10 17:11:10 $
 **
 ** Content and meta data layer support for the FAT file system 
 **
@@ -1050,9 +1050,7 @@ inode_walk_dent_act(FS_INFO * fs, FS_DENT * fs_dent, int flags, void *ptr)
     if (fs->file_walk(fs, fs_dent->fsi, 0, 0,
 	    FS_FLAG_FILE_SLACK | FS_FLAG_FILE_AONLY |
 	    FS_FLAG_FILE_RECOVER, inode_walk_file_act, ptr)) {
-	tsk_errno = 0;
-	tsk_errstr[0] = '\0';
-	tsk_errstr2[0] = '\0';
+	tsk_error_reset();
     }
 
     return WALK_CONT;
@@ -1299,7 +1297,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 		if (fatfs_dinode_copy(fatfs, fs_inode, dep, sect, inum)) {
 		    /* Ignore this error and continue */
 		    if (tsk_errno == TSK_ERR_FS_UNICODE) {
-			tsk_errno = 0;
+			tsk_error_reset();
 			continue;
 		    }
 		    else {
@@ -1473,7 +1471,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 
 		if (fatfs_dinode_copy(fatfs, fs_inode, dep, sect, inum)) {
 		    if (tsk_errno == TSK_ERR_FS_UNICODE) {
-			tsk_errno = 0;
+			tsk_error_reset();
 			continue;
 		    }
 		    else {
@@ -1687,7 +1685,11 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	}
     }
 
-    /* A deleted file that we want to recover */
+    /* A deleted file that we want to recover 
+     * In this case, we could get a lot of errors because of inconsistent
+     * data.  TO make it clear that these are from a recovery, we set most
+     * error codes to _RECOVER so that they can be more easily suppressed.
+     */
     else if ((fs_inode->flags & FS_FLAG_META_UNALLOC) &&
 	(flags & FS_FLAG_FILE_RECOVER)) {
 
@@ -1712,7 +1714,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	sbase = FATFS_CLUST_2_SECT(fatfs, startclust);
 
 	if (sbase > fs->last_block) {
-	    tsk_errno = TSK_ERR_FS_INODE_INT;
+	    tsk_errno = TSK_ERR_FS_RECOVER;
 	    snprintf(tsk_errstr, TSK_ERRSTR_L,
 		"fatfs_file_walk: Starting cluster address too large (recovery): %"
 		PRIuDADDR, sbase);
@@ -1725,6 +1727,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	 * recover it */
 	retval = is_clustalloc(fatfs, startclust);
 	if (retval == -1) {
+	    tsk_errno = TSK_ERR_FS_RECOVER;
 	    data_buf_free(data_buf);
 	    return 1;
 	}
@@ -1772,6 +1775,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	    /* Skip allocated clusters */
 	    retval = is_clustalloc(fatfs, clust);
 	    if (retval == -1) {
+		tsk_errno = TSK_ERR_FS_RECOVER;
 		data_buf_free(data_buf);
 		return 1;
 	    }
@@ -1805,6 +1809,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	    /* Skip allocated clusters */
 	    retval = is_clustalloc(fatfs, clust);
 	    if (retval == -1) {
+		tsk_errno = TSK_ERR_FS_RECOVER;
 		data_buf_free(data_buf);
 		return 1;
 	    }
@@ -1842,8 +1847,9 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 
 		if (verbose)
 		    fprintf(stderr,
-			"fatfs_file_walk: Processing %d bytes of sector %"
-			PRIuDADDR " for recovery\n", len, (sbase + i));
+			"fatfs_file_walk: Processing %" PRIu32
+			" bytes of sector %" PRIuDADDR " for recovery\n",
+			len, (sbase + i));
 
 		retval =
 		    action(fs, sbase + i,
@@ -1928,8 +1934,9 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 
 		if (verbose)
 		    fprintf(stderr,
-			"fatfs_file_walk: Processing %d bytes of sector %"
-			PRIuDADDR "\n", len, (sbase + i));
+			"fatfs_file_walk: Processing %" PRIu32
+			" bytes of sector %" PRIuDADDR "\n", len,
+			(sbase + i));
 
 		retval =
 		    action(fs, sbase + i,
@@ -2257,7 +2264,7 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
     fprintf(hFile, "--------------------------------------------\n");
     fprintf(hFile, "Sector Size: %" PRIu16 "\n", fatfs->ssize);
     fprintf(hFile, "Cluster Size: %" PRIu32 "\n",
-	fatfs->csize * fatfs->ssize);
+	(uint32_t) fatfs->csize * fatfs->ssize);
 
     fprintf(hFile, "Total Cluster Range: 2 - %" PRIuDADDR "\n",
 	fatfs->lastclust);
@@ -2474,9 +2481,7 @@ fatfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 		FS_FLAG_FILE_NOID), print_addr_act, (void *) &print)) {
 	fprintf(hFile, "\nError reading file\n");
 	tsk_error_print(hFile);
-	tsk_errno = 0;
-	tsk_errstr[0] = '\0';
-	tsk_errstr2[0] = '\0';
+	tsk_error_reset();
     }
     else if (print.idx != 0) {
 	fprintf(hFile, "\n");
