@@ -2,7 +2,7 @@
 ** fatfs_dent
 ** The Sleuth Kit 
 **
-** $Date: 2006/05/08 17:56:51 $
+** $Date: 2006/07/05 18:24:09 $
 **
 ** Human interface Layer support for the FAT file system
 **
@@ -546,9 +546,7 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 			    PRIuINUM "\n", fs_dent->inode);
 			tsk_error_print(stderr);
 		    }
-		    tsk_errno = 0;
-		    tsk_errstr[0] = '\0';
-
+		    tsk_error_reset();
 		}
 
 		dinfo->depth--;
