@@ -2,7 +2,7 @@
 ** ffind  (file find)
 ** The Sleuth Kit 
 **
-** $Date: 2006/04/06 01:15:55 $
+** $Date: 2006/07/10 13:26:20 $
 **
 ** Find the file that uses the specified inode (including deleted files)
 ** 
@@ -31,15 +31,14 @@ usage()
     fprintf(stderr, "\t-a: Find all occurrences\n");
     fprintf(stderr, "\t-d: Find deleted entries ONLY\n");
     fprintf(stderr, "\t-u: Find undeleted entries ONLY\n");
-    fprintf(stderr, "\t-i imgtype: The format of the image file\n");
+    fprintf(stderr,
+	"\t-f fstype: Image file system type (use '-f list' for supported types)\n");
+    fprintf(stderr,
+	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
     fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
     fprintf(stderr, "\t-v: Verbose output to stderr\n");
     fprintf(stderr, "\t-V: Print version\n");
-    fprintf(stderr, "\t-f fstype: Image file system type\n");
-    fs_print_types(stderr);
-    fprintf(stderr, "Supported image format types:\n");
-    img_print_types(stderr);
 
     exit(1);
 }
@@ -75,9 +74,19 @@ main(int argc, char **argv)
 	    break;
 	case 'f':
 	    fstype = optarg;
+	    if (strcmp(fstype, "list") == 0) {
+		fs_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 	case 'i':
 	    imgtype = optarg;
+	    if (strcmp(imgtype, "list") == 0) {
+		img_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 	case 'o':
 	    if ((imgoff = parse_offset(optarg)) == -1) {
