@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2006/05/11 15:53:21 $
+** $Date: 2006/07/10 17:11:10 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -71,7 +71,8 @@ ffs_group_load(FFS_INFO * ffs, FFS_GRPNUM_T grp_num)
 		tsk_errstr[0] = '\0';
 	    }
 	    snprintf(tsk_errstr2, TSK_ERRSTR_L,
-		"ffs_group_load: Group %d at %" PRIuDADDR, grp_num, addr);
+		"ffs_group_load: Group %" PRI_FFSGRP " at %" PRIuDADDR,
+		grp_num, addr);
 	    return 1;
 	}
     }
@@ -1027,7 +1028,10 @@ ffs_file_walk_direct(FS_INFO * fs, DATA_BUF * buf,
     read_count = (length < buf->size ? length : buf->size);
 
     if (addr > fs->last_block) {
-	tsk_errno = TSK_ERR_FS_INODE_INT;
+	if (flags & FS_FLAG_FILE_RECOVER)
+	    tsk_errno = TSK_ERR_FS_RECOVER;
+	else
+	    tsk_errno = TSK_ERR_FS_INODE_INT;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "ffs: Invalid direct address (too large): %"
 	    PRIuDADDR "", addr);
@@ -1108,7 +1112,10 @@ ffs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
 	    level, addr);
 
     if (addr > fs->last_block) {
-	tsk_errno = TSK_ERR_FS_INODE_INT;
+	if (flags & FS_FLAG_FILE_RECOVER)
+	    tsk_errno = TSK_ERR_FS_RECOVER;
+	else
+	    tsk_errno = TSK_ERR_FS_INODE_INT;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "ffs: Indirect block address too large: %" PRIuDADDR "", addr);
 	tsk_errstr2[0] = '\0';
@@ -1163,7 +1170,10 @@ ffs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
 	    OFF_T prevcnt = todo_count;
 
 	    if (getu32(fs, (uint8_t *) & iaddr[n]) > fs->last_block) {
-		tsk_errno = TSK_ERR_FS_INODE_INT;
+		if (flags & FS_FLAG_FILE_RECOVER)
+		    tsk_errno = TSK_ERR_FS_RECOVER;
+		else
+		    tsk_errno = TSK_ERR_FS_INODE_INT;
 		snprintf(tsk_errstr, TSK_ERRSTR_L,
 		    "ffs: Address in indirect block too large: %"
 		    PRIu32 "", getu32(fs, (uint8_t *) & iaddr[n]));
@@ -1194,7 +1204,10 @@ ffs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
 	    OFF_T prevcnt = todo_count;
 
 	    if (getu64(fs, (uint8_t *) & iaddr[n]) > fs->last_block) {
-		tsk_errno = TSK_ERR_FS_INODE_INT;
+		if (flags & FS_FLAG_FILE_RECOVER)
+		    tsk_errno = TSK_ERR_FS_RECOVER;
+		else
+		    tsk_errno = TSK_ERR_FS_INODE_INT;
 		snprintf(tsk_errstr, TSK_ERRSTR_L,
 		    "ffs: Address in indirect block too large: %"
 		    PRIuDADDR "", getu64(fs, (uint8_t *) & iaddr[n]));
@@ -1228,7 +1241,8 @@ ffs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
  * flag values: FS_FLAG_FILE_SPARSE, FS_FLAG_FILE_AONLY, FS_FLAG_FILE_SLACK
  *  FS_FLAG_FILE_META
  *
- * nothing special is done for FS_FLAG_FILE_RECOVER
+ * If FS_FLAG_FILE_RECOVER is set, then many error codes are set to _RECOVER
+ * so that errors can be suppressed.  NO special recovery logic is used. 
  *
  * Action uses: FS_FLAG_DATA_CONT, FS_FLAG_DATA_META
  * @@@ DATA_ALLOC and _UNALLOC are not implemented
