@@ -2,7 +2,7 @@
 ** ffs_dent
 ** The  Sleuth Kit 
 **
-** $Date: 2006/04/13 16:05:25 $
+** $Date: 2006/07/05 18:24:09 $
 **
 ** File name layer for a FFS/UFS image 
 **
@@ -282,9 +282,7 @@ ffs_dent_parse_block(FFS_INFO * ffs, FFS_DINFO * dinfo, char *buf,
 			PRIuINUM "\n", fs_dent->inode);
 		    tsk_error_print(stderr);
 		}
-		tsk_errno = 0;
-		tsk_errstr[0] = '\0';
-		tsk_errstr2[0] = '\0';
+		tsk_error_reset();
 	    }
 
 	    dinfo->depth--;
