@@ -2,7 +2,7 @@
 ** fs_open
 ** The Sleuth Kit 
 **
-** $Date: 2006/04/07 18:12:00 $
+** $Date: 2006/07/05 21:12:59 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -28,12 +28,18 @@
 
 #include "fs_tools.h"
 
-/* fs_open - open a file system */
+/* 
+ * fs_open - open a file system 
+ *
+ * offset is the byte offset in the image to the start of 
+ * the file system 
+ */
 
 FS_INFO *
 fs_open(IMG_INFO * img_info, SSIZE_T offset, const char *type)
 {
 
+
     /* We will try different file systems ... 
      * We need to try all of them in case more than one matches
      */
@@ -41,14 +47,17 @@ fs_open(IMG_INFO * img_info, SSIZE_T offset, const char *type)
 	FS_INFO *fs_info, *fs_set = NULL;
 	char *set = NULL;
 
+	if (verbose)
+	    fprintf(stderr,
+		"fsopen: Auto detection mode at offset %" PRIuOFF "\n",
+		offset);
+
 	if ((fs_info = ntfs_open(img_info, offset, NTFS, 1)) != NULL) {
 	    set = "NTFS";
 	    fs_set = fs_info;
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 
 	if ((fs_info = fatfs_open(img_info, offset, FATAUTO, 1)) != NULL) {
@@ -66,9 +75,7 @@ fs_open(IMG_INFO * img_info, SSIZE_T offset, const char *type)
 	    }
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 
 	if ((fs_info = ext2fs_open(img_info, offset, EXTAUTO, 1)) != NULL) {
@@ -86,9 +93,7 @@ fs_open(IMG_INFO * img_info, SSIZE_T offset, const char *type)
 	    }
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 
 	if ((fs_info = ffs_open(img_info, offset, FFSAUTO)) != NULL) {
@@ -106,9 +111,7 @@ fs_open(IMG_INFO * img_info, SSIZE_T offset, const char *type)
 	    }
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 
 	/*
@@ -140,9 +143,7 @@ fs_open(IMG_INFO * img_info, SSIZE_T offset, const char *type)
 	    fs_set = fs_info;
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 
 
