@@ -2,7 +2,7 @@
 ** fs_tools
 ** The Sleuth Kit 
 **
-** $Date: 2006/05/11 15:53:21 $
+** $Date: 2006/07/10 15:09:56 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -26,19 +26,27 @@ extern "C" {
      */
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 #include <fcntl.h>
-#include <sys/fcntl.h>
-#include <sys/param.h>
+
 #include <sys/types.h>
-#include <sys/time.h>
 #include <time.h>
 #include <locale.h>
 #include <errno.h>
 
 #include "tsk_os.h"
+
+#if defined (HAVE_UNISTD)
+#include <unistd.h>
+#endif
+
+#if !defined (TSK_WIN32)
+#include <sys/fcntl.h>
+#include <sys/param.h>
+#include <sys/time.h>
+#endif
+
 #include "tsk_types.h"
 
 #include "libauxtools.h"
@@ -240,6 +248,7 @@ extern "C" {
 	FS_DATA_RUN *run;	/* a linked list of data runs */
 	OFF_T runlen;		/* number of bytes that are allocated in
 				 * original run (larger than size) */
+	uint64_t compsize;	/* size of the compression unit */
 
 	/* stream data (resident) */
 	size_t buflen;		/* allocated bytes in buf */
@@ -269,12 +278,26 @@ extern "C" {
 	OFF_T size;		/* file size */
 	uid_t uid;		/* owner */
 	gid_t gid;		/* group */
+
 	/* @@@ Need to make these 64-bits ... ? */
 	time_t mtime;		/* last modified */
 	time_t atime;		/* last access */
 	time_t ctime;		/* last status change */
-	time_t crtime;		/* create time (NTFS only: not used by ils) */
-	time_t dtime;		/* delete time (Linux only) */
+
+	/* filesystem specific times */
+	union {
+	    struct {		/* NTFS Times */
+		time_t crtime;	/* create time */
+	    };
+	    struct {		/* Linux Times */
+		time_t dtime;	/* delete time */
+	    };
+	    struct {		/* HFS Times */
+		time_t bkup_time;
+		time_t attr_mtime;
+	    };
+	};
+
 	DADDR_T *direct_addr;	/* direct blocks */
 	int direct_count;	/* number of blocks */
 	DADDR_T *indir_addr;	/* indirect blocks */
