@@ -2,7 +2,7 @@
 ** icat 
 ** The Sleuth Kit 
 **
-** $Date: 2006/05/08 17:56:51 $
+** $Date: 2006/07/10 17:11:10 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -36,16 +36,17 @@ usage()
 	progname);
     fprintf(stderr, "\t-h: Do not display holes in sparse files\n");
     fprintf(stderr, "\t-r: Recover deleted file\n");
+    fprintf(stderr,
+	"\t-R: Recover deleted file and suppress recovery errors\n");
     fprintf(stderr, "\t-s: Display slack space at end of file\n");
-    fprintf(stderr, "\t-i imgtype: The format of the image file\n");
+    fprintf(stderr,
+	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
+    fprintf(stderr,
+	"\t-f fstype: File system type (use '-f list' for supported types)\n");
     fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
     fprintf(stderr, "\t-v: verbose to stderr\n");
     fprintf(stderr, "\t-V: Print version\n");
-    fprintf(stderr, "\t-f fstype: File system type\n");
-    fs_print_types(stderr);
-    fprintf(stderr, "Supported image format types:\n");
-    img_print_types(stderr);
 
     exit(1);
 }
@@ -66,11 +67,12 @@ main(int argc, char **argv)
     int id_used = 0;
     int retval;
     SSIZE_T imgoff = 0;
+    int suppress_recover_error = 0;
 
     progname = argv[0];
     setlocale(LC_ALL, "");
 
-    while ((ch = getopt(argc, argv, "f:hi:o:rsvV")) > 0) {
+    while ((ch = getopt(argc, argv, "f:hi:o:rRsvV")) > 0) {
 	switch (ch) {
 	case '?':
 	default:
@@ -78,12 +80,22 @@ main(int argc, char **argv)
 	    usage();
 	case 'f':
 	    fstype = optarg;
+	    if (strcmp(fstype, "list") == 0) {
+		fs_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 	case 'h':
 	    flags |= FS_FLAG_FILE_NOSPARSE;
 	    break;
 	case 'i':
 	    imgtype = optarg;
+	    if (strcmp(imgtype, "list") == 0) {
+		img_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 	case 'o':
 	    if ((imgoff = parse_offset(optarg)) == -1) {
@@ -94,6 +106,10 @@ main(int argc, char **argv)
 	case 'r':
 	    flags |= FS_FLAG_FILE_RECOVER;
 	    break;
+	case 'R':
+	    flags |= FS_FLAG_FILE_RECOVER;
+	    suppress_recover_error = 1;
+	    break;
 	case 's':
 	    flags |= FS_FLAG_FILE_SLACK;
 	    break;
@@ -195,14 +211,18 @@ main(int argc, char **argv)
 	retval = fs_icat(fs, 0, inum, type, id, flags | FS_FLAG_FILE_NOID);
 
     if (retval) {
-	tsk_error_print(stderr);
-	fs->close(fs);
-	img->close(img);
-	exit(1);
-
+	if ((suppress_recover_error == 1)
+	    && (tsk_errno == TSK_ERR_FS_RECOVER)) {
+	    tsk_error_reset();
+	}
+	else {
+	    tsk_error_print(stderr);
+	    fs->close(fs);
+	    img->close(img);
+	    exit(1);
+	}
     }
     fs->close(fs);
     img->close(img);
-
     exit(0);
 }
