@@ -2,7 +2,7 @@
 ** ifind (inode find)
 ** The Sleuth Kit
 **
-** $Date: 2006/04/06 01:15:55 $
+** $Date: 2006/07/10 13:26:20 $
 **
 ** Given an image  and block number, identify which inode it is used by
 ** 
@@ -38,16 +38,15 @@ usage()
     fprintf(stderr, "\t-n file: Find the meta data given the file name\n");
     fprintf(stderr,
 	"\t-p par_addr: Find UNALLOCATED MFT entries given the parent's meta address (NTFS only)\n");
-    fprintf(stderr, "\t-i imgtype: The format of the image file\n");
+    fprintf(stderr,
+	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
+    fprintf(stderr,
+	"\t-f fstype: File system type (use '-f list' for supported types)\n");
     fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
     fprintf(stderr, "\t-v: Verbose output to stderr\n");
     fprintf(stderr, "\t-V: Print version\n");
     fprintf(stderr, "\t-z ZONE: Time zone setting when -l -p is given\n");
-    fprintf(stderr, "\t-f fstype: File system type\n");
-    fs_print_types(stderr);
-    fprintf(stderr, "Supported image format types:\n");
-    img_print_types(stderr);
 
     exit(1);
 }
@@ -98,9 +97,19 @@ main(int argc, char **argv)
 
 	case 'f':
 	    fstype = optarg;
+	    if (strcmp(fstype, "list") == 0) {
+		fs_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 	case 'i':
 	    imgtype = optarg;
+	    if (strcmp(imgtype, "list") == 0) {
+		img_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 
 	case 'l':
