@@ -1,9 +1,10 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2005/09/02 19:53:28 $
+** $Date: 2006/04/05 03:47:36 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
+** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
 **
 ** TASK
@@ -43,8 +44,12 @@ print_header(FS_INFO * fs)
     char hostnamebuf[BUFSIZ];
     time_t now;
 
-    if (gethostname(hostnamebuf, sizeof(hostnamebuf) - 1) < 0)
-	error("gethostname: %m");
+    if (gethostname(hostnamebuf, sizeof(hostnamebuf) - 1) < 0) {
+	if (verbose)
+	    fprintf(stderr, "error getting host by name\n");
+
+	strcpy(hostnamebuf, "unknown");
+    }
     hostnamebuf[sizeof(hostnamebuf) - 1] = 0;
     now = time((time_t *) 0);
 
@@ -68,8 +73,11 @@ print_header_mac()
     char hostnamebuf[BUFSIZ];
     time_t now;
 
-    if (gethostname(hostnamebuf, sizeof(hostnamebuf) - 1) < 0)
-	error("gethostname: %m");
+    if (gethostname(hostnamebuf, sizeof(hostnamebuf) - 1) < 0) {
+	if (verbose)
+	    fprintf(stderr, "Error getting host by name\n");
+	strcpy(hostnamebuf, "unknown");
+    }
     hostnamebuf[sizeof(hostnamebuf) - 1] = 0;
     now = time((time_t *) 0);
 
@@ -102,10 +110,10 @@ ils_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 	fs_inode->ctime -= sec_skew;
     }
     printf("%" PRIuINUM "|%c|%d|%d|%lu|%lu|%lu",
-	   fs_inode->addr, (flags & FS_FLAG_META_ALLOC) ? 'a' : 'f',
-	   (int) fs_inode->uid, (int) fs_inode->gid,
-	   (ULONG) fs_inode->mtime, (ULONG) fs_inode->atime,
-	   (ULONG) fs_inode->ctime);
+	fs_inode->addr, (flags & FS_FLAG_META_ALLOC) ? 'a' : 'f',
+	(int) fs_inode->uid, (int) fs_inode->gid,
+	(ULONG) fs_inode->mtime, (ULONG) fs_inode->atime,
+	(ULONG) fs_inode->ctime);
 
     if (sec_skew != 0) {
 	fs_inode->mtime += sec_skew;
@@ -114,10 +122,10 @@ ils_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
     }
 
     printf("|%lo|%d|%" PRIuOFF "|%" PRIuDADDR "|%" PRIuDADDR "\n",
-	   (ULONG) fs_inode->mode, (int) fs_inode->nlink,
-	   fs_inode->size,
-	   (fs_inode->direct_count > 0) ? fs_inode->direct_addr[0] : 0,
-	   (fs_inode->direct_count > 1) ? fs_inode->direct_addr[1] : 0);
+	(ULONG) fs_inode->mode, (int) fs_inode->nlink,
+	fs_inode->size,
+	(fs_inode->direct_count > 0) ? fs_inode->direct_addr[0] : 0,
+	(fs_inode->direct_count > 1) ? fs_inode->direct_addr[1] : 0);
 
     return WALK_CONT;
 }
@@ -134,13 +142,13 @@ ils_mac_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 
     /* ADD NAME IF WE GOT IT */
     printf("0|<%s-%s%s%s-%" PRIuINUM ">|0|%" PRIuINUM "|%d|", image,
-	   (fs_inode->name) ? fs_inode->name->name : "",
-	   (fs_inode->name) ? "-" : "",
-	   (flags & FS_FLAG_META_ALLOC) ? "alive" : "dead", fs_inode->addr,
-	   fs_inode->addr, (int) fs_inode->mode);
+	(fs_inode->name) ? fs_inode->name->name : "",
+	(fs_inode->name) ? "-" : "",
+	(flags & FS_FLAG_META_ALLOC) ? "alive" : "dead", fs_inode->addr,
+	fs_inode->addr, (int) fs_inode->mode);
 
     /* Print the "ls" mode in ascii format */
-    make_ls(fs_inode->mode, ls, 12);
+    make_ls(fs_inode->mode, ls);
 
     if (sec_skew != 0) {
 	fs_inode->mtime -= sec_skew;
@@ -149,10 +157,10 @@ ils_mac_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
     }
 
     printf("%s|%d|%d|%d|0|%" PRIuOFF "|%lu|%lu|%lu|%lu|0\n",
-	   ls, (int) fs_inode->nlink, (int) fs_inode->uid,
-	   (int) fs_inode->gid, fs_inode->size,
-	   (ULONG) fs_inode->atime, (ULONG) fs_inode->mtime,
-	   (ULONG) fs_inode->ctime, (ULONG) fs->block_size);
+	ls, (int) fs_inode->nlink, (int) fs_inode->uid,
+	(int) fs_inode->gid, fs_inode->size,
+	(ULONG) fs_inode->atime, (ULONG) fs_inode->mtime,
+	(ULONG) fs_inode->ctime, (ULONG) fs->block_size);
 
     if (sec_skew != 0) {
 	fs_inode->mtime -= sec_skew;
@@ -165,9 +173,10 @@ ils_mac_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 
 
 
+/* return 1 on error and 0 on success */
 uint8_t
 fs_ils(FS_INFO * fs, uint8_t lclflags, INUM_T istart, INUM_T ilast,
-       int flags, int32_t skew, char *img)
+    int flags, int32_t skew, char *img)
 {
     sec_skew = skew;
 
@@ -182,11 +191,13 @@ fs_ils(FS_INFO * fs, uint8_t lclflags, INUM_T istart, INUM_T ilast,
 
 	print_header_mac();
 
-	fs->inode_walk(fs, istart, ilast, flags, ils_mac_act, NULL);
+	if (fs->inode_walk(fs, istart, ilast, flags, ils_mac_act, NULL))
+	    return 1;
     }
     else {
 	print_header(fs);
-	fs->inode_walk(fs, istart, ilast, flags, ils_act, NULL);
+	if (fs->inode_walk(fs, istart, ilast, flags, ils_act, NULL))
+	    return 1;
     }
 
     return 0;
