@@ -60,7 +60,9 @@
 #include "mymalloc.h"
 #include "fs_data.h"
 #include <ctype.h>
+#if !defined (_WIN32)
 #include <netinet/in.h>
+#endif
 #include "fs_unicode.h"
 
 /* free all memory used by inode linked list */
@@ -99,7 +101,7 @@ parse_rockridge(FS_INFO * fs, char *buf, int count)
     char *end = buf + count - 1;
 
     if (verbose)
-	fprintf(stderr, "parse_rockridge: count is: %" PRIu32 " ", count);
+	fprintf(stderr, "parse_rockridge: count is: %d\n", count);
 
     rr = (rockridge_ext *) mymalloc(sizeof(rockridge_ext));
     if (rr == NULL) {
@@ -194,7 +196,7 @@ iso9660_get_dentrys(FS_INFO * fs, OFF_T offs, int count, int type,
     if (verbose)
 	fprintf(stderr,
 	    "iso9660_get_dentrys: fs: %lu offs: %lu"
-	    " count: %" PRIu32 " type: %" PRIu32 " fn: %lu\n",
+	    " count: %d type: %d fn: %lu\n",
 	    (ULONG) fs, (ULONG) offs, count, type, (ULONG) fn);
 
     in = (in_node *) mymalloc(sizeof(in_node));
@@ -1148,7 +1150,7 @@ iso9660_fsstat(FS_INFO * fs, FILE * hFile)
 
 	fprintf(hFile, "\nMETADATA INFORMATION\n");
 	fprintf(hFile, "--------------------------------------------\n");
-	fprintf(hFile, "Path Table is at block: %d\n",
+	fprintf(hFile, "Path Table is at block: %" PRIu32 "\n",
 	    (fs->endian & TSK_LIT_ENDIAN) ?
 	    getu32(fs, p->pvd.loc_l) : getu32(fs, p->pvd.loc_m));
 
@@ -1244,7 +1246,7 @@ iso9660_fsstat(FS_INFO * fs, FILE * hFile)
 
 	fprintf(hFile, "\nMETADATA INFORMATION\n");
 	fprintf(hFile, "--------------------------------------------\n");
-	fprintf(hFile, "Path Table is at block: %d\n",
+	fprintf(hFile, "Path Table is at block: %" PRIu32 "\n",
 	    (fs->endian & TSK_LIT_ENDIAN) ?
 	    getu32(fs, s->svd.loc_l) : getu32(fs, s->svd.loc_m));
 
@@ -1392,7 +1394,7 @@ iso9660_print_rockridge(FILE * hFile, rockridge_ext * rr)
 	mode_buf[9] = 'T';
 
     fprintf(hFile, "%s\n", mode_buf);
-    fprintf(hFile, "Number links: %d\n", rr->nlink);
+    fprintf(hFile, "Number links: %" PRIu32 "\n", rr->nlink);
 
     fprintf(hFile, "Alternate name: %s\n", rr->fn);
     fprintf(hFile, "\n");
@@ -1447,12 +1449,15 @@ iso9660_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
     putchar('\n');
 
     fprintf(hFile, "Name: %s\n", iso->dinode->fn);
-    fprintf(hFile, "Size: %d\n", parseu32(fs, iso->dinode->dr.data_len));
+    fprintf(hFile, "Size: %" PRIu32 "\n", parseu32(fs,
+	    iso->dinode->dr.data_len));
 
     if (iso->dinode->ea) {
 	fprintf(hFile, "\nEXTENDED ATTRIBUTE INFO\n");
-	fprintf(hFile, "Owner-ID: %d\n", getu32(fs, iso->dinode->ea->uid));
-	fprintf(hFile, "Group-ID: %d\n", getu32(fs, iso->dinode->ea->gid));
+	fprintf(hFile, "Owner-ID: %" PRIu32 "\n", getu32(fs,
+		iso->dinode->ea->uid));
+	fprintf(hFile, "Group-ID: %" PRIu32 "\n", getu32(fs,
+		iso->dinode->ea->gid));
 	fprintf(hFile, "Mode: %s\n", make_unix_perm(fs, &dd));
     }
     else if (iso->dinode->rr) {
