@@ -2,7 +2,7 @@
 ** istat
 ** The Sleuth Kit 
 **
-** $Date: 2006/05/08 17:56:51 $
+** $Date: 2006/07/10 13:26:20 $
 **
 ** Display all inode info about a given inode.
 **
@@ -38,15 +38,14 @@ usage()
 	"\t-z zone: time zone of original machine (i.e. EST5EDT or GMT)\n");
     fprintf(stderr,
 	"\t-s seconds: Time skew of original machine (in seconds)\n");
-    fprintf(stderr, "\t-i imgtype: The format of the image file\n");
+    fprintf(stderr,
+	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
+    fprintf(stderr,
+	"\t-f fstype: File system type (use '-f list' for supported types)\n");
     fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
     fprintf(stderr, "\t-v: verbose output to stderr\n");
     fprintf(stderr, "\t-V: print version\n");
-    fprintf(stderr, "\t-f fstype: File system type\n");
-    fs_print_types(stderr);
-    fprintf(stderr, "Supported image format types:\n");
-    img_print_types(stderr);
     exit(1);
 }
 
@@ -89,9 +88,19 @@ main(int argc, char **argv)
 	    break;
 	case 'f':
 	    fstype = optarg;
+	    if (strcmp(fstype, "list") == 0) {
+		fs_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 	case 'i':
 	    imgtype = optarg;
+	    if (strcmp(imgtype, "list") == 0) {
+		img_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 
 	case 'o':
