@@ -2,7 +2,7 @@
 ** jls
 ** The Sleuth Kit 
 **
-** $Date: 2006/04/06 01:15:56 $
+** $Date: 2006/07/10 13:26:20 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -51,15 +51,14 @@ usage()
     fprintf(stderr,
 	"usage: %s [-f fstype] [-i imgtype] [-o imgoffset] [-vV] image [inode]\n",
 	progname);
-    fprintf(stderr, "\t-i imgtype: The format of the image file\n");
+    fprintf(stderr,
+	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
+    fprintf(stderr,
+	"\t-f fstype: File system type (use '-f list' for supported types)\n");
     fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
     fprintf(stderr, "\t-v: verbose output to stderr\n");
     fprintf(stderr, "\t-V: print version\n");
-    fprintf(stderr, "\t-f fstype: File system type\n");
-    fs_print_types(stderr);
-    fprintf(stderr, "Supported image format types:\n");
-    img_print_types(stderr);
     exit(1);
 }
 
@@ -87,9 +86,19 @@ main(int argc, char **argv)
 	    usage();
 	case 'f':
 	    fstype = optarg;
+	    if (strcmp(fstype, "list") == 0) {
+		fs_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 	case 'i':
 	    imgtype = optarg;
+	    if (strcmp(imgtype, "list") == 0) {
+		img_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 
 	case 'o':
