@@ -2,7 +2,7 @@
 ** ntfs_dent
 ** The Sleuth Kit
 **
-** $Date: 2006/05/08 17:56:51 $
+** $Date: 2006/07/05 18:24:09 $
 **
 ** name layer support for the NTFS file system
 **
@@ -311,6 +311,7 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 	if ((myflags & FS_FLAG_NAME_ALLOC) &&
 	    (flags & FS_FLAG_NAME_RECURSE) &&
 	    (!ISDOT(fs_dent->name)) &&
+	    (fs_dent->fsi) &&
 	    ((fs_dent->fsi->mode & FS_INODE_FMT) == FS_INODE_DIR) &&
 	    (fs_dent->inode)) {
 
@@ -327,8 +328,7 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 		    flags, action, ptr)) {
 		if (verbose)
 		    fprintf(stderr, "Error recursing into directory\n");
-		tsk_errno = 0;
-
+		tsk_error_reset();
 	    }
 
 	    dinfo->depth--;
