@@ -1,5 +1,5 @@
 /*
- * $Date: 2006/05/11 16:27:14 $
+ * $Date: 2006/06/20 22:35:40 $
  *
  * Joachim Metz <forensics@hoffmannbv.nl>, Hoffmann Investigations
  * Copyright (c) 2006 Joachim Metz.  All rights reserved 
@@ -11,11 +11,12 @@
  */
 
 #include "img_tools.h"
+#if defined(USE_LIBEWF)
 #include "ewf.h"
 
 
 static SSIZE_T
-ewf_image_read_random(IMG_INFO * img_info, SSIZE_T vol_offset, char *buf,
+ewf_image_read_random(IMG_INFO * img_info, OFF_T vol_offset, char *buf,
     OFF_T len, OFF_T offset)
 {
     SSIZE_T cnt;
@@ -166,3 +167,4 @@ ewf_open(int num_img, const char **images, IMG_INFO * next)
 
     return img_info;
 }
+#endif
