@@ -1,5 +1,5 @@
 /*
- * $Date: 2006/04/24 20:24:23 $
+ * $Date: 2006/07/05 18:24:09 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -11,14 +11,20 @@
  * This software is distributed under the Common Public License 1.0
  *
  */
-
+#include <sys/stat.h>
 #include <string.h>
 #include "img_tools.h"
 
 #include "raw.h"
 #include "split.h"
+
+#if defined(USE_LIBAFF)
 #include "aff.h"
+#endif
+
+#if defined(USE_LIBEWF)
 #include "ewf.h"
+#endif
 
 /*
  * type is a list of types: "raw", "split", "split,raid", 
@@ -61,21 +67,32 @@ img_open(const char *type, const int num_img, const char **images)
     if (type == NULL) {
 	IMG_INFO *img_set = NULL;
 	char *set = NULL;
+	struct stat stat_buf;
+
+	/* First verify that the image file exists */
+	if (stat(images[0], &stat_buf) == -1) {
+	    tsk_errno = TSK_ERR_IMG_STAT;
+	    snprintf(tsk_errstr, TSK_ERRSTR_L, "%s : %s", images[0],
+		strerror(errno));
+	    tsk_errstr2[0] = '\0';
+	    return NULL;
+	}
 
 	// we rely on tsk_errno, so make sure it is 0
-	tsk_errno = 0;
+	tsk_error_reset();
 
 	/* Try the non-raw formats first */
+#if defined(USE_LIBAFF)
 	if ((img_info = aff_open(images, NULL)) != NULL) {
 	    set = "AFF";
 	    img_set = img_info;
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
+#endif
 
+#if defined(USE_LIBEWF)
 	if ((img_info = ewf_open(num_img, images, NULL)) != NULL) {
 	    if (set == NULL) {
 		set = "EWF";
@@ -91,10 +108,9 @@ img_open(const char *type, const int num_img, const char **images)
 	    }
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
+#endif
 
 	if (img_set != NULL)
 	    return img_set;
@@ -168,15 +184,19 @@ img_open(const char *type, const int num_img, const char **images)
 	    img_tmp = NULL;
 	    break;
 
+#if defined(USE_LIBAFF)
 	case AFF_AFF:
 	case AFF_AFD:
 	case AFF_AFM:
 	    img_info = aff_open(img_tmp, img_info);
 	    break;
+#endif
 
+#if defined(USE_LIBEWF)
 	case EWF_EWF:
 	    img_info = ewf_open(num_img_tmp, img_tmp, img_info);
 	    break;
+#endif
 
 	default:
 	    tsk_errno = TSK_ERR_IMG_UNSUPTYPE;
