@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/05/11 16:12:55 $
+ * $Date: 2006/06/20 22:35:41 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved 
@@ -16,11 +16,15 @@ extern "C" {
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
 
 #include "tsk_os.h"
+
+#ifdef HAVE_UNISTD
+#include <unistd.h>
+#endif
+
 #include "tsk_types.h"
 
 #include "img_types.h"
@@ -39,7 +43,7 @@ extern "C" {
 	OFF_T size;		/* Size of image in bytes */
 
 	/* Read random */
-	 SSIZE_T(*read_random) (IMG_INFO *, SSIZE_T, char *, OFF_T, OFF_T);
+	 SSIZE_T(*read_random) (IMG_INFO *, OFF_T, char *, OFF_T, OFF_T);
 	 OFF_T(*get_size) (IMG_INFO *);
 	void (*close) (IMG_INFO *);
 	void (*imgstat) (IMG_INFO *, FILE *);
