@@ -1,5 +1,5 @@
 /*
- * $Date: 2006/05/11 16:12:19 $
+ * $Date: 2006/07/05 18:54:16 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -11,6 +11,7 @@
  *
  */
 
+
 #include <sys/stat.h>
 #include "img_tools.h"
 #include "raw.h"
@@ -18,7 +19,7 @@
 
 /* Return the size read and -1 if error */
 static SSIZE_T
-raw_read_random(IMG_INFO * img_info, SSIZE_T vol_offset, char *buf,
+raw_read_random(IMG_INFO * img_info, OFF_T vol_offset, char *buf,
     OFF_T len, OFF_T offset)
 {
     SSIZE_T cnt;
@@ -37,8 +38,42 @@ raw_read_random(IMG_INFO * img_info, SSIZE_T vol_offset, char *buf,
 
     // Read the data
     else {
-	off_t tot_offset = offset + vol_offset;
+	OFF_T tot_offset = offset + vol_offset;
 
+#ifdef TSK_WIN32
+	{
+	    DWORD nread;
+
+	    if (raw_info->seek_pos != tot_offset) {
+		LONG lo, hi;
+		OFF_T max = (OFF_T) MAXLONG + 1;
+
+		hi = (LONG) (tot_offset / max);
+		lo = (LONG) (tot_offset - max * hi);
+
+		if (FALSE == SetFilePointer(raw_info->fd, lo, &hi,
+			FILE_BEGIN)) {
+		    tsk_errno = TSK_ERR_IMG_SEEK;
+		    snprintf(tsk_errstr, TSK_ERRSTR_L,
+			"raw_read_random - %" PRIuOFF, tot_offset);
+		    tsk_errstr2[0] = '\0';
+		    return -1;
+		}
+		raw_info->seek_pos = tot_offset;
+	    }
+
+	    if (FALSE == ReadFile(raw_info->fd, buf, (DWORD) len,
+		    &nread, NULL)) {
+		tsk_errno = TSK_ERR_IMG_READ;
+		snprintf(tsk_errstr, TSK_ERRSTR_L,
+		    "raw_read_random - offset: %" PRIuOFF " - len: %"
+		    PRIuOFF, tot_offset, len);
+		tsk_errstr2[0] = '\0';
+		return -1;
+	    }
+	    cnt = (SSIZE_T) nread;
+	}
+#else
 	if (raw_info->seek_pos != tot_offset) {
 	    if (lseek(raw_info->fd, tot_offset, SEEK_SET) != tot_offset) {
 		tsk_errno = TSK_ERR_IMG_SEEK;
@@ -60,6 +95,7 @@ raw_read_random(IMG_INFO * img_info, SSIZE_T vol_offset, char *buf,
 	    tsk_errstr2[0] = '\0';
 	    return -1;
 	}
+#endif
 	raw_info->seek_pos += cnt;
 	return cnt;
     }
@@ -85,7 +121,11 @@ void
 raw_close(IMG_INFO * img_info)
 {
     IMG_RAW_INFO *raw_info = (IMG_RAW_INFO *) img_info;
+#ifdef TSK_WIN32
+    CloseHandle(raw_info->fd);
+#else
     close(raw_info->fd);
+#endif
 }
 
 
@@ -126,7 +166,8 @@ raw_open(const char **images, IMG_INFO * next)
 	/* Exit if we are given a directory */
 	if (stat(images[0], &stat_buf) == -1) {
 	    tsk_errno = TSK_ERR_IMG_STAT;
-	    snprintf(tsk_errstr, TSK_ERRSTR_L, "raw_open directory check");
+	    snprintf(tsk_errstr, TSK_ERRSTR_L,
+		"raw_open directory check: %s", strerror(errno));
 	    tsk_errstr2[0] = '\0';
 	    return NULL;
 	}
@@ -142,6 +183,28 @@ raw_open(const char **images, IMG_INFO * next)
 	    return NULL;
 	}
 
+#ifdef TSK_WIN32
+	{
+	    /* Convert to wide chars */
+	    WCHAR img_name[1024];
+	    unsigned int i;
+	    for (i = 0; i < strlen(images[0]) && i < 1023; i++) {
+		img_name[i] = images[0][i];
+	    }
+	    img_name[i] = '\0';
+
+	    if ((raw_info->fd = CreateFile(img_name, GENERIC_READ,
+			0, 0, OPEN_EXISTING, 0, 0)) ==
+		INVALID_HANDLE_VALUE) {
+		tsk_errno = TSK_ERR_IMG_OPEN;
+		snprintf(tsk_errstr, TSK_ERRSTR_L,
+		    "raw_open file: %s msg: %s", images[0],
+		    strerror(errno));
+		tsk_errstr2[0] = '\0';
+		return NULL;
+	    }
+	}
+#else
 	if ((raw_info->fd = open(images[0], O_RDONLY)) < 0) {
 	    tsk_errno = TSK_ERR_IMG_OPEN;
 	    snprintf(tsk_errstr, TSK_ERRSTR_L, "raw_open file: %s msg: %s",
@@ -149,7 +212,9 @@ raw_open(const char **images, IMG_INFO * next)
 	    tsk_errstr2[0] = '\0';
 	    return NULL;
 	}
-
+#endif
+	/* We don't use the stat output because it doesn't work on raw
+	 * devices and such */
 	img_info->size = lseek(raw_info->fd, 0, SEEK_END);
 	lseek(raw_info->fd, 0, SEEK_SET);
 	raw_info->seek_pos = 0;
