@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/04/12 22:18:20 $
+ * $Date: 2006/06/20 22:35:41 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved 
@@ -18,8 +18,12 @@ extern "C" {
     typedef struct IMG_RAW_INFO IMG_RAW_INFO;
     struct IMG_RAW_INFO {
 	IMG_INFO img_info;
+#ifdef TSK_WIN32
+	HANDLE fd;
+#else
 	int fd;
-	off_t seek_pos;
+#endif
+	OFF_T seek_pos;
     };
 
 #ifdef __cplusplus
