@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/04/12 22:18:20 $
+ * $Date: 2006/06/19 21:54:27 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved 
@@ -18,13 +18,11 @@ extern "C" {
 
 #define SPLIT_CACHE	15
 
-    typedef struct IMG_SPLIT_CACHE IMG_SPLIT_CACHE;
-
-    struct IMG_SPLIT_CACHE {
+    typedef struct {
 	int fd;
 	int image;
-	off_t seek_pos;
-    };
+	OFF_T seek_pos;
+    } IMG_SPLIT_CACHE;
 
     typedef struct IMG_SPLIT_INFO IMG_SPLIT_INFO;
 
