@@ -51,7 +51,7 @@
 #include <string.h>
 #include <zlib.h>
 
-#include "endian.h"
+#include "libewf_endian.h"
 #include "notify.h"
 #include "md5.h"
 
@@ -67,6 +67,7 @@
 #include "ewf_section.h"
 #include "ewf_sectors.h"
 #include "ewf_volume.h"
+#include "ewf_volume_smart.h"
 #include "ewf_table.h"
 #include "file.h"
 #include "handle.h"
@@ -181,51 +182,93 @@ void libewf_section_header2_read( LIBEWF_HANDLE *handle, int file_descriptor, si
  */
 void libewf_section_volume_read( LIBEWF_HANDLE *handle, int file_descriptor, size_t size )
 {
-	EWF_VOLUME *volume;
 	EWF_CRC calculated_crc;
 	EWF_CRC stored_crc;
-	uint32_t bytes_per_chunk;
-	uint32_t volume_chunk_count;
+	EWF_VOLUME *volume             = NULL;
+	EWF_VOLUME_SMART *volume_smart = NULL;
+	uint32_t bytes_per_chunk       = 0;
+	uint32_t volume_chunk_count    = 0;
 
 	if( handle == NULL )
 	{
 		LIBEWF_FATAL_PRINT( "libewf_section_volume_read: incorrect handle.\n" );
 	}
-	if( size != EWF_VOLUME_SIZE )
+	if( size == EWF_VOLUME_SIZE )
+	{
+		volume = ewf_volume_read( file_descriptor );
+
+#ifdef _LIBEWF_DEBUG_
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown1, 4 ); );
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown2, 16 ); );
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown3, 4 ); );
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown4, 12 ); );
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown5, 3 ); );
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown6, 4 ); );
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown7, 963 ); );
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->signature, 5 ); );
+#endif
+
+		calculated_crc  = ewf_crc( (void *) volume, ( EWF_VOLUME_SIZE - EWF_CRC_SIZE ), 1 );
+		stored_crc      = convert_32bit( volume->crc );
+		bytes_per_chunk = ewf_volume_calculate_chunk_size( volume );
+
+		if( stored_crc != calculated_crc )
+		{
+			LIBEWF_WARNING_PRINT( "libewf_section_volume_read: crc does not match (in file: %" PRIu32 ", calculated: %" PRIu32 ")\n", stored_crc, calculated_crc );
+		}
+		LIBEWF_VERBOSE_PRINT( "libewf_section_volume_read: This volume has %" PRIu32 " chunks of %" PRIu32 " bytes each, crc %" PRIu32 " (%" PRIu32 ")\n", volume->chunk_count, bytes_per_chunk, stored_crc, calculated_crc );
+
+		volume_chunk_count        = convert_32bit( volume->chunk_count );
+		handle->chunk_count       = convert_32bit( volume->chunk_count );
+	        handle->sectors_per_chunk = convert_32bit( volume->sectors_per_chunk );
+	        handle->bytes_per_sector  = convert_32bit( volume->bytes_per_sector );
+	        handle->sector_count      = convert_32bit( volume->sector_count );
+	        handle->media_type        = convert_32bit( volume->unknown3 );
+	        handle->compression_level = volume->compression_level;
+
+		memcpy( (uint8_t *) handle->guid, (uint8_t *) volume->guid, 16 );
+
+		ewf_volume_free( volume );
+	}
+	else if( size == EWF_VOLUME_SMART_SIZE )
+	{
+		volume_smart = ewf_volume_smart_read( file_descriptor );
+
+#ifdef _LIBEWF_DEBUG_
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume_smart->unknown1, 4 ); );
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume_smart->unknown2, 20 ); );
+		LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume_smart->unknown3, 45 ); );
+#endif
+
+		calculated_crc  = ewf_crc( (void *) volume_smart, ( EWF_VOLUME_SMART_SIZE - EWF_CRC_SIZE ), 1 );
+		stored_crc      = convert_32bit( volume_smart->crc );
+		bytes_per_chunk = ewf_volume_smart_calculate_chunk_size( volume_smart );
+
+		if( stored_crc != calculated_crc )
+		{
+			LIBEWF_WARNING_PRINT( "libewf_section_volume_read: crc does not match (in file: %" PRIu32 ", calculated: %" PRIu32 ")\n", stored_crc, calculated_crc );
+		}
+		LIBEWF_VERBOSE_PRINT( "libewf_section_volume_read: This volume has %" PRIu32 " chunks of %" PRIu32 " bytes each, crc %" PRIu32 " (%" PRIu32 ")\n", volume->chunk_count, bytes_per_chunk, stored_crc, calculated_crc );
+
+		volume_chunk_count        = convert_32bit( volume_smart->chunk_count );
+		handle->chunk_count       = convert_32bit( volume_smart->chunk_count );
+	        handle->sectors_per_chunk = convert_32bit( volume_smart->sectors_per_chunk );
+	        handle->bytes_per_sector  = convert_32bit( volume_smart->bytes_per_sector );
+	        handle->sector_count      = convert_32bit( volume_smart->sector_count );
+	        handle->media_type        = convert_32bit( volume_smart->unknown3 );
+
+		ewf_volume_smart_free( volume_smart );
+	}
+	else
 	{
 		LIBEWF_FATAL_PRINT( "libewf_section_volume_read: mismatch in section data size.\n" );
 	}
-	volume = ewf_volume_read( file_descriptor );
-
-#ifdef _LIBEWF_DEBUG_
-	LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown1, 4 ); );
-	LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown2, 16 ); );
-	LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown3, 4 ); );
-	LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown4, 12 ); );
-	LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown5, 3 ); );
-	LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown6, 4 ); );
-	LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->unknown7, 963 ); );
-	LIBEWF_VERBOSE_EXEC( libewf_dump_data( volume->signature, 5 ); );
-#endif
-
-	calculated_crc  = ewf_crc( (void *) volume, ( EWF_VOLUME_SIZE - EWF_CRC_SIZE ), 1 );
-	stored_crc      = convert_32bit( volume->crc );
-	bytes_per_chunk = ewf_volume_calculate_chunk_size( volume );
-
-	if( stored_crc != calculated_crc )
-	{
-		LIBEWF_WARNING_PRINT( "libewf_section_volume_read: crc does not match (in file: %" PRIu32 ", calculated: %" PRIu32 ")\n", stored_crc, calculated_crc );
-	}
-	LIBEWF_VERBOSE_PRINT( "libewf_section_volume_read: This volume has %" PRIu32 " chunks of %" PRIu32 " bytes each, crc %" PRIu32 " (%" PRIu32 ")\n", volume->chunk_count, bytes_per_chunk, stored_crc, calculated_crc );
-
 	if( handle->chunk_size != bytes_per_chunk )
 	{
 		handle = libewf_handle_cache_realloc( handle, bytes_per_chunk );
 
 		handle->chunk_size = bytes_per_chunk;
 	}
-	volume_chunk_count = convert_32bit( volume->chunk_count );
-
 	if( volume_chunk_count == 0 )
 	{
 		LIBEWF_VERBOSE_PRINT( "libewf_section_volume_read: compensating for 0 volume chunk count.\n" );
@@ -234,17 +277,6 @@ void libewf_section_volume_read( LIBEWF_HANDLE *handle, int file_descriptor, siz
 	}
 	handle->offset_table           = libewf_offset_table_values_alloc( handle->offset_table, volume_chunk_count );
 	handle->secondary_offset_table = libewf_offset_table_values_alloc( handle->secondary_offset_table, volume_chunk_count );
-
-	handle->chunk_count       = convert_32bit( volume->chunk_count );
-        handle->sectors_per_chunk = convert_32bit( volume->sectors_per_chunk );
-        handle->bytes_per_sector  = convert_32bit( volume->bytes_per_sector );
-        handle->sector_count      = convert_32bit( volume->sector_count );
-        handle->media_type        = convert_32bit( volume->unknown3 );
-        handle->compression_level = volume->compression_level;
-
-	memcpy( (uint8_t *) handle->guid, (uint8_t *) volume->guid, 16 );
-
-	ewf_volume_free( volume );
 }
 
 /* Fills the offset table
@@ -881,12 +913,7 @@ int64_t libewf_read_random( LIBEWF_HANDLE *handle, void *buffer, uint64_t size,
 			 * minus the 4 bytes for the CRC
 			 */
 			chunk_data_size = chunk_read_count - EWF_CRC_SIZE;
-
-			if( chunk_data_size > handle->chunk_size )
-			{
-				LIBEWF_FATAL_PRINT( "libewf_read_random: size of chunk larger than specified chunk size.\n" );
-			}
-			is_compressed = 0;
+			is_compressed   = 0;
 
 			if( handle->alternative_read_method == 1 )
 			{
@@ -910,6 +937,10 @@ int64_t libewf_read_random( LIBEWF_HANDLE *handle, void *buffer, uint64_t size,
 					is_compressed = 1;
 				}
 			}
+			if( chunk_data_size > handle->chunk_size )
+			{
+				LIBEWF_FATAL_PRINT( "libewf_read_random: size of chunk larger than specified chunk size.\n" );
+			}
 			if( is_compressed == 1 )
 			{
 				raw_data_size = handle->chunk_size;
@@ -1014,7 +1045,7 @@ int64_t libewf_read_to_file_descriptor( LIBEWF_HANDLE *handle, int output_file_d
 	}
 	LIBEWF_MD5_INIT( &md5 );
 
-	data = (char *) malloc( handle->chunk_size );
+	data = (char *) malloc( sizeof( char ) * handle->chunk_size );
 
 	if( data == NULL )
 	{
