@@ -47,7 +47,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <time.h>
 
 #include "definitions.h"
 #include "notify.h"
@@ -224,6 +223,12 @@ char **libewf_split_string( char *string, int delimiter, uint32_t *amount )
 			}
 			lines[ iterator ][ line_size ] = '\0';
 
+			/* Correct if first value is empty
+			 */
+			if( line_end == string )
+			{
+				line_start += 1;
+			}
 			iterator++;
 		}
 	}
@@ -355,16 +360,17 @@ char *libewf_convert_date_header_value( char *header_value, uint8_t date_format
 
 /* Generate date string within a header value
  */
-char *libewf_generate_date_header_value( void )
+char *libewf_generate_date_header_value( time_t timestamp )
 {
 	char *date_string        = libewf_header_value_string_alloc( 20 );
-	time_t timestamp         = time( NULL );
 	struct tm *time_elements = localtime( &timestamp );
 
 	snprintf( date_string, 20, "%4d %d %d %d %d %d",
 		( time_elements->tm_year + 1900 ), ( time_elements->tm_mon + 1 ), time_elements->tm_mday,
 		time_elements->tm_hour, time_elements->tm_min, time_elements->tm_sec );
 
+	date_string[ 19 ] = '\0';
+
 	return( date_string );
 }
 
@@ -404,12 +410,13 @@ char *libewf_convert_date_header2_value( char *header_value, uint8_t date_format
 
 /* Generate date string within a header2 value
  */
-char *libewf_generate_date_header2_value( void )
+char *libewf_generate_date_header2_value( time_t timestamp )
 {
-	char *date_string = libewf_header_value_string_alloc( 20 );
-	time_t timestamp  = time( NULL );
+	char *date_string = libewf_header_value_string_alloc( 11 );
 
-	snprintf( date_string, 20, "%" PRIu32, (uint32_t) timestamp );
+	snprintf( date_string, 11, "%" PRIu32, (uint32_t) timestamp );
+
+	date_string[ 10 ] = '\0';
 
 	return( date_string );
 }
@@ -662,7 +669,7 @@ void libewf_header_values_fprint( FILE *stream, LIBEWF_HEADER_VALUES *header_val
 
 /* Generate an Encase3 header
  */
-EWF_HEADER *libewf_header_values_generate_header_string_encase3( LIBEWF_HEADER_VALUES *header_values, uint8_t compression_level )
+EWF_HEADER *libewf_header_values_generate_header_string_encase3( LIBEWF_HEADER_VALUES *header_values, time_t timestamp, uint8_t compression_level )
 {
 	EWF_HEADER *header;
 	char *header_string_head       = "1\r\nmain\r\nc\tn\ta\te\tt\tav\tov\tm\tu\tp\tr\r\n";
@@ -717,7 +724,7 @@ EWF_HEADER *libewf_header_values_generate_header_string_encase3( LIBEWF_HEADER_V
 	}
 	else
 	{
-		acquiry_date = libewf_generate_date_header_value();
+		acquiry_date = libewf_generate_date_header_value( timestamp );
 		size        += strlen( acquiry_date );
 	}
 	if( header_values->system_date != NULL )
@@ -727,7 +734,7 @@ EWF_HEADER *libewf_header_values_generate_header_string_encase3( LIBEWF_HEADER_V
 	}
 	else
 	{
-		system_date = libewf_generate_date_header_value();
+		system_date = libewf_generate_date_header_value( timestamp );
 		size       += strlen( system_date );
 	}
 	if( header_values->acquiry_operating_system != NULL )
@@ -790,13 +797,13 @@ EWF_HEADER *libewf_header_values_generate_header_string_encase3( LIBEWF_HEADER_V
 
 	/* Make sure the string is terminated
 	 */
-	header[ size ] = '\0';
+	header[ size - 1 ] = '\0';
 
-	if( header_values->acquiry_date != NULL )
+	if( header_values->acquiry_date == NULL )
 	{
 		free( acquiry_date );
 	}
-	if( header_values->system_date != NULL )
+	if( header_values->system_date == NULL )
 	{
 		free( system_date );
 	}
@@ -805,7 +812,7 @@ EWF_HEADER *libewf_header_values_generate_header_string_encase3( LIBEWF_HEADER_V
 
 /* Generate an Encase4 header
  */
-EWF_HEADER *libewf_header_values_generate_header_string_encase4( LIBEWF_HEADER_VALUES *header_values )
+EWF_HEADER *libewf_header_values_generate_header_string_encase4( LIBEWF_HEADER_VALUES *header_values, time_t timestamp )
 {
 	EWF_HEADER *header;
 	char *header_string_head       = "1\r\nmain\r\nc\tn\ta\te\tt\tav\tov\tm\tu\tp\r\n";
@@ -859,7 +866,7 @@ EWF_HEADER *libewf_header_values_generate_header_string_encase4( LIBEWF_HEADER_V
 	}
 	else
 	{
-		acquiry_date = libewf_generate_date_header2_value();
+		acquiry_date = libewf_generate_date_header_value( timestamp );
 		size        += strlen( acquiry_date );
 	}
 	if( header_values->system_date != NULL )
@@ -869,7 +876,124 @@ EWF_HEADER *libewf_header_values_generate_header_string_encase4( LIBEWF_HEADER_V
 	}
 	else
 	{
-		system_date = libewf_generate_date_header2_value();
+		system_date = libewf_generate_date_header_value( timestamp );
+		size       += strlen( system_date );
+	}
+	if( header_values->acquiry_operating_system != NULL )
+	{
+		size                    += strlen( header_values->acquiry_operating_system );
+		acquiry_operating_system = header_values->acquiry_operating_system;
+	}
+	if( header_values->acquiry_software_version != NULL )
+	{
+		size                    += strlen( header_values->acquiry_software_version );
+		acquiry_software_version = header_values->acquiry_software_version;
+	}
+	if( header_values->password != NULL )
+	{
+		size         += strlen( header_values->password );
+		password_hash = header_values->password;
+	}
+	else
+	{
+		size         += 1;
+		password_hash = "0";
+	}
+	size += strlen( header_string_tail );
+
+	/* allow for 9x \t and 1x \0
+	 */
+	size += 10;
+
+	header = ewf_header_alloc( size );
+
+	snprintf( (char *) header, size, "%s%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s%s",
+		header_string_head, description, case_number, evidence_number, examiner_name,
+		notes, acquiry_software_version, acquiry_operating_system, acquiry_date,
+		system_date, password_hash, header_string_tail );
+
+	/* Make sure the string is terminated
+	 */
+	header[ size - 1 ] = '\0';
+
+	if( header_values->acquiry_date == NULL )
+	{
+		free( acquiry_date );
+	}
+	if( header_values->system_date == NULL )
+	{
+		free( system_date );
+	}
+	return( header );
+}
+
+/* Generate an Encase4 header2
+ */
+EWF_HEADER *libewf_header_values_generate_header2_string_encase4( LIBEWF_HEADER_VALUES *header_values, time_t timestamp )
+{
+	EWF_HEADER *header;
+	char *header_string_head       = "1\nmain\na\tc\tn\te\tt\tav\tov\tm\tu\tp\n";
+	char *header_string_tail       = "\n\n";
+	char *case_number              = "";
+	char *description              = "";
+	char *examiner_name            = "";
+	char *evidence_number          = "";
+	char *notes                    = "";
+	char *system_date              = "";
+	char *acquiry_date             = "";
+	char *acquiry_operating_system = "";
+	char *acquiry_software_version = "";
+	char *password_hash            = "";
+
+	size_t size = strlen( header_string_head );
+
+	if( header_values == NULL )
+	{
+		LIBEWF_FATAL_PRINT( "libewf_header_values_generate_header2_string_encase4: invalid header values.\n" );
+	}
+	if( header_values->case_number != NULL )
+	{
+		size       += strlen( header_values->case_number );
+		case_number = header_values->case_number;
+	}
+	if( header_values->description != NULL )
+	{
+		size       += strlen( header_values->description );
+		description = header_values->description;
+	}
+	if( header_values->examiner_name != NULL )
+	{
+		size         += strlen( header_values->examiner_name );
+		examiner_name = header_values->examiner_name;
+	}
+	if( header_values->evidence_number != NULL )
+	{
+		size           += strlen( header_values->evidence_number );
+		evidence_number = header_values->evidence_number;
+	}
+	if( header_values->notes != NULL )
+	{
+		size += strlen( header_values->notes );
+		notes = header_values->notes;
+	}
+	if( header_values->acquiry_date != NULL )
+	{
+		size        += strlen( header_values->acquiry_date );
+		acquiry_date = header_values->acquiry_date;
+	}
+	else
+	{
+		acquiry_date = libewf_generate_date_header2_value( timestamp );
+		size        += strlen( acquiry_date );
+	}
+	if( header_values->system_date != NULL )
+	{
+		size       += strlen( header_values->system_date );
+		system_date = header_values->system_date;
+	}
+	else
+	{
+		system_date = libewf_generate_date_header2_value( timestamp );
 		size       += strlen( system_date );
 	}
 	if( header_values->acquiry_operating_system != NULL )
@@ -896,19 +1020,19 @@ EWF_HEADER *libewf_header_values_generate_header_string_encase4( LIBEWF_HEADER_V
 	header = ewf_header_alloc( size );
 
 	snprintf( (char *) header, size, "%s%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s%s",
-		header_string_head, description, case_number, evidence_number, examiner_name,
+		header_string_head, case_number, evidence_number, description, examiner_name,
 		notes, acquiry_software_version, acquiry_operating_system, acquiry_date,
 		system_date, password_hash, header_string_tail );
 
 	/* Make sure the string is terminated
 	 */
-	header[ size ] = '\0';
+	header[ size - 1 ] = '\0';
 
-	if( header_values->acquiry_date != NULL )
+	if( header_values->acquiry_date == NULL )
 	{
 		free( acquiry_date );
 	}
-	if( header_values->system_date != NULL )
+	if( header_values->system_date == NULL )
 	{
 		free( system_date );
 	}
@@ -917,13 +1041,13 @@ EWF_HEADER *libewf_header_values_generate_header_string_encase4( LIBEWF_HEADER_V
 
 /* Generate an Encase5 header2
  */
-EWF_HEADER *libewf_header_values_generate_header2_string_encase5( LIBEWF_HEADER_VALUES *header_values )
+EWF_HEADER *libewf_header_values_generate_header2_string_encase5( LIBEWF_HEADER_VALUES *header_values, time_t timestamp )
 {
 	EWF_HEADER *header;
-	char *header_string_main       = "3\r\nmain\r\na\tc\tn\te\tt\tav\tov\tm\tu\tp\tdc\r\n";
-	char *header_string_tail       = "\r\n\r\n";
-	char *header_string_srce       = "srce\r\n0\t1\r\np\tn\tid\tev\ttb\tlo\tpo\tah\tgu\taq\r\n0\t0\t\t\t\t\t\t\t\t\r\n\t\t\t\t\t-1\t-1\t\t\t\r\n\r\n";
-	char *header_string_sub        = "sub\r\n0\t1\r\np\tn\tid\tnu\tco\tgu\r\n0\t0\t\t\t\t\r\n\t\t\t\t1\t\r\n\r\n";
+	char *header_string_main       = "3\nmain\na\tc\tn\te\tt\tav\tov\tm\tu\tp\tdc\n";
+	char *header_string_tail       = "\n\n";
+	char *header_string_srce       = "srce\n0\t1\np\tn\tid\tev\ttb\tlo\tpo\tah\tgu\taq\n0\t0\t\t\t\t\t\t\t\t\n\t\t\t\t\t-1\t-1\t\t\t\n\n";
+	char *header_string_sub        = "sub\n0\t1\np\tn\tid\tnu\tco\tgu\n0\t0\t\t\t\t\n\t\t\t\t1\t\n\n";
 	char *case_number              = "";
 	char *description              = "";
 	char *examiner_name            = "";
@@ -976,7 +1100,7 @@ EWF_HEADER *libewf_header_values_generate_header2_string_encase5( LIBEWF_HEADER_
 	}
 	else
 	{
-		acquiry_date = libewf_generate_date_header2_value();
+		acquiry_date = libewf_generate_date_header2_value( timestamp );
 		size        += strlen( acquiry_date );
 	}
 	if( header_values->system_date != NULL )
@@ -986,7 +1110,7 @@ EWF_HEADER *libewf_header_values_generate_header2_string_encase5( LIBEWF_HEADER_
 	}
 	else
 	{
-		system_date = libewf_generate_date_header2_value();
+		system_date = libewf_generate_date_header2_value( timestamp );
 		size       += strlen( system_date );
 	}
 	if( header_values->acquiry_operating_system != NULL )
@@ -1025,13 +1149,13 @@ EWF_HEADER *libewf_header_values_generate_header2_string_encase5( LIBEWF_HEADER_
 
 	/* Make sure the string is terminated
 	 */
-	header[ size ] = '\0';
+	header[ size - 1 ] = '\0';
 
-	if( header_values->acquiry_date != NULL )
+	if( header_values->acquiry_date == NULL )
 	{
 		free( acquiry_date );
 	}
-	if( header_values->system_date != NULL )
+	if( header_values->system_date == NULL )
 	{
 		free( system_date );
 	}
@@ -1040,7 +1164,7 @@ EWF_HEADER *libewf_header_values_generate_header2_string_encase5( LIBEWF_HEADER_
 
 /* Generate an FTK Imager header
  */
-EWF_HEADER *libewf_header_values_generate_header_string_ftk( LIBEWF_HEADER_VALUES *header_values, uint8_t compression_level )
+EWF_HEADER *libewf_header_values_generate_header_string_ftk( LIBEWF_HEADER_VALUES *header_values, time_t timestamp, uint8_t compression_level )
 {
 	EWF_HEADER *header;
 	char *header_string_head       = "1\nmain\nc\tn\ta\te\tt\tav\tov\tm\tu\tp\tr\n";
@@ -1095,7 +1219,7 @@ EWF_HEADER *libewf_header_values_generate_header_string_ftk( LIBEWF_HEADER_VALUE
 	}
 	else
 	{
-		acquiry_date = libewf_generate_date_header_value();
+		acquiry_date = libewf_generate_date_header_value( timestamp );
 		size        += strlen( acquiry_date );
 	}
 	if( header_values->system_date != NULL )
@@ -1105,7 +1229,7 @@ EWF_HEADER *libewf_header_values_generate_header_string_ftk( LIBEWF_HEADER_VALUE
 	}
 	else
 	{
-		system_date = libewf_generate_date_header_value();
+		system_date = libewf_generate_date_header_value( timestamp );
 		size       += strlen( system_date );
 	}
 	if( header_values->acquiry_operating_system != NULL )
@@ -1168,13 +1292,13 @@ EWF_HEADER *libewf_header_values_generate_header_string_ftk( LIBEWF_HEADER_VALUE
 
 	/* Make sure the string is terminated
 	 */
-	header[ size ] = '\0';
+	header[ size - 1 ] = '\0';
 
-	if( header_values->acquiry_date != NULL )
+	if( header_values->acquiry_date == NULL )
 	{
 		free( acquiry_date );
 	}
-	if( header_values->system_date != NULL )
+	if( header_values->system_date == NULL )
 	{
 		free( system_date );
 	}
