@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/04/07 21:21:03 $
+ * $Date: 2006/07/05 19:16:34 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -755,6 +755,11 @@ dos_load_ext_table(MM_INFO * mm, DADDR_T sect_cur, DADDR_T sect_ext_base,
 		snprintf(tsk_errstr, TSK_ERRSTR_L,
 		    "dos_load_ext_table: Starting sector too large for image");
 		tsk_errstr2[0] = '\0';
+		if (verbose)
+		    fprintf(stderr,
+			"Starting sector %" PRIuDADDR
+			" too large for image\n",
+			sect_ext_base + part_start);
 		return 1;
 	    }
 
@@ -781,6 +786,10 @@ dos_load_ext_table(MM_INFO * mm, DADDR_T sect_cur, DADDR_T sect_ext_base,
 		snprintf(tsk_errstr, TSK_ERRSTR_L,
 		    "dos_load_ext_table: Starting sector too large for image");
 		tsk_errstr2[0] = '\0';
+		if (verbose)
+		    fprintf(stderr,
+			"Starting sector %" PRIuDADDR
+			" too large for image\n", sect_cur + part_start);
 		return 1;
 	    }
 	    if (NULL == mm_part_add(mm, (DADDR_T) (sect_cur + part_start),
@@ -809,7 +818,7 @@ static uint8_t
 dos_load_prim_table(MM_INFO * mm, uint8_t test)
 {
     dos_sect sect;
-    int i;
+    int i, added = 0;
     char *table_str;
     SSIZE_T cnt;
     DADDR_T taddr = mm->offset / mm->block_size + DOS_PART_SOFFSET;
@@ -875,6 +884,13 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
 	    tsk_errstr2[0] = '\0';
 	    return 1;
 	}
+	else if (strncmp("FAT", sect.oemname, 4) == 0) {
+	    tsk_errno = TSK_ERR_MM_MAGIC;
+	    snprintf(tsk_errstr, TSK_ERRSTR_L,
+		"dos_load_prim_table: FAT OEM name exists");
+	    tsk_errstr2[0] = '\0';
+	    return 1;
+	}
     }
 
     /* Add an entry of 1 sector for the table  to the internal structure */
@@ -907,6 +923,11 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
 	    snprintf(tsk_errstr, TSK_ERRSTR_L,
 		"dos_load_prim_table: Starting sector too large for image");
 	    tsk_errstr2[0] = '\0';
+	    if (verbose)
+		fprintf(stderr,
+		    "Starting sector %" PRIuDADDR " too large for image\n",
+		    part_start);
+
 	    return 1;
 	}
 #if 0
@@ -920,6 +941,8 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
 	}
 #endif
 
+	added = 1;
+
 	/* Add the partition to the internal structure 
 	 * If it is an extended partition, process it now */
 	if (dos_is_ext(part->ptype)) {
@@ -938,6 +961,17 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
 		return 1;
 	}
     }
+    if (added == 0) {
+	if (verbose)
+	    fprintf(stderr, "dos_load_prim: No valid entries\n");
+
+	tsk_errno = TSK_ERR_MM_MAGIC;
+	snprintf(tsk_errstr, TSK_ERRSTR_L,
+	    "dos_load_prim_table: No valid entries in primary table");
+	tsk_errstr2[0] = '\0';
+	return 1;
+    }
+
     return 0;
 }
 
