@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/04/07 21:21:03 $
+ * $Date: 2006/05/22 15:55:46 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -119,7 +119,7 @@ gpt_load_table(MM_INFO * mm)
 	tsk_errno = TSK_ERR_MM_MAGIC;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "Header reports partition entry size of %" PRIu32
-	    " and not %lu", ent_size, sizeof(gpt_entry));
+	    " and not %d", ent_size, sizeof(gpt_entry));
 	tsk_errstr2[0] = '\0';
 	return 1;
     }
