@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/04/07 21:21:03 $
+ * $Date: 2006/06/19 22:21:28 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -98,9 +98,9 @@ mac_load_table(MM_INFO * mm)
 
 	if (verbose)
 	    fprintf(stderr,
-		"mac_load: %d  Starting Sector: %" PRIu32 "  Size: %"
-		PRIu32 " Type: %s\n", idx, part_start, part_size,
-		part.type);
+		"mac_load: %" PRIu32 "  Starting Sector: %" PRIu32
+		"  Size: %" PRIu32 " Type: %s\n", idx, part_start,
+		part_size, part.type);
 
 	if (part_size == 0)
 	    continue;
