@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/04/06 01:15:57 $
+ * $Date: 2006/07/05 18:24:09 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -41,9 +41,7 @@ mm_open(IMG_INFO * img_info, DADDR_T offset, const char *type)
 	    mm_set = mm_info;
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 	if ((mm_info = bsd_open(img_info, offset)) != NULL) {
 	    // if (set == NULL) {
@@ -65,9 +63,7 @@ mm_open(IMG_INFO * img_info, DADDR_T offset, const char *type)
 	     */
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 	if ((mm_info = gpt_open(img_info, offset)) != NULL) {
 	    if (set == NULL) {
@@ -85,9 +81,7 @@ mm_open(IMG_INFO * img_info, DADDR_T offset, const char *type)
 	    }
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 
 	if ((mm_info = sun_open(img_info, offset)) != NULL) {
@@ -106,9 +100,7 @@ mm_open(IMG_INFO * img_info, DADDR_T offset, const char *type)
 	    }
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 
 	if ((mm_info = mac_open(img_info, offset)) != NULL) {
@@ -127,9 +119,7 @@ mm_open(IMG_INFO * img_info, DADDR_T offset, const char *type)
 	    }
 	}
 	else {
-	    tsk_errno = 0;
-	    tsk_errstr[0] = '\0';
-	    tsk_errstr2[0] = '\0';
+	    tsk_error_reset();
 	}
 
 	if (mm_set == NULL) {
