@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/04/07 21:21:03 $
+ * $Date: 2006/06/20 22:35:42 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -20,14 +20,21 @@ extern "C" {
      */
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <stdlib.h>
 #include <fcntl.h>
-#include <sys/param.h>
+
 #include <sys/types.h>
 #include <string.h>
 
 #include "tsk_os.h"
+
+#if defined(HAVE_UNISTD)
+#include <unistd.h>
+#endif
+#if !defined (TSK_WIN32)
+#include <sys/param.h>
+#endif
+
 #include "tsk_types.h"
 
 #include "libauxtools.h"
