@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2005/09/02 23:34:04 $
+ * $Date: 2006/03/22 03:41:48 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -31,11 +31,13 @@ MM_TYPES mm_open_table[] = {
     {0},
 };
 
-/* parse the string and return the value */
+/* parse the string and return the value 
+ *
+ * Returns MM_UNSUPP if string cannot be parsed
+ * */
 char
 mm_parse_type(const char *str)
 {
-
     MM_TYPES *types;
 
     for (types = mm_open_table; types->name; types++) {
@@ -43,7 +45,6 @@ mm_parse_type(const char *str)
 	    return types->code;
 	}
     }
-
     return MM_UNSUPP;
 }
 
@@ -51,10 +52,17 @@ void
 mm_print_types(FILE * hFile)
 {
     MM_TYPES *types;
+    fprintf(hFile, "Supported partition types:\n");
     for (types = mm_open_table; types->name; types++)
 	fprintf(hFile, "\t%s (%s)\n", types->name, types->comment);
 }
 
+
+/*
+ * Return the string name of a partition type given its code
+ *
+ * Returns NULL if a match is not made
+ * */
 char *
 mm_get_type(char mmtype)
 {
