@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/05/11 15:48:12 $
+ * $Date: 2006/07/10 13:26:20 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -31,8 +31,10 @@ usage()
     fprintf(stderr,
 	"%s [-i imgtype] [-o imgoffset] [-brvV] [-t mmtype] image [images]\n",
 	progname);
-    fprintf(stderr, "\t-t mmtype: The type of partition system\n");
-    fprintf(stderr, "\t-i imgtype: The format of the image file\n");
+    fprintf(stderr,
+	"\t-t mmtype: The type of partition system (use '-t list' for list of supported types)\n");
+    fprintf(stderr,
+	"\t-i imgtype: The format of the image file (use '-i list' for list supported types)\n");
     fprintf(stderr,
 	"\t-o imgoffset: Offset to the start of the volume that contains the partition system (in sectors)\n");
     fprintf(stderr, "\t-b: print the rounded length in bytes\n");
@@ -40,9 +42,6 @@ usage()
 	"\t-r: recurse and look for other partition tables in partitions (DOS Only)\n");
     fprintf(stderr, "\t-v: verbose output\n");
     fprintf(stderr, "\t-V: print the version\n");
-    mm_print_types(stderr);
-    fprintf(stderr, "Supported image formats:\n");
-    img_print_types(stderr);
     exit(1);
 }
 
@@ -60,7 +59,7 @@ part_act(MM_INFO * mm, PNUM_T pnum, MM_PART * part, int flag, char *ptr)
 
     /* Table was not given, but slot was */
     else if ((part->table_num == -1) && (part->slot_num != -1))
-	printf("%.2" PRIuPNUM ":  %.2" PRIuPNUM "      ",
+	printf("%.2" PRIuPNUM ":  %.2" PRIu8 "      ",
 	    pnum, part->slot_num);
 
     /* The Table was given, but slot wasn't */
@@ -158,6 +157,11 @@ main(int argc, char **argv)
 	    break;
 	case 'i':
 	    imgtype = optarg;
+	    if (strcmp(imgtype, "list") == 0) {
+		img_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 
 	case 'o':
@@ -171,6 +175,11 @@ main(int argc, char **argv)
 	    break;
 	case 't':
 	    mmtype = optarg;
+	    if (strcmp(mmtype, "list") == 0) {
+		mm_print_types(stderr);
+		exit(1);
+	    }
+
 	    break;
 	case 'v':
 	    verbose++;
@@ -231,13 +240,13 @@ main(int argc, char **argv)
 		print_header(mm);
 		if (mm->part_walk(mm, mm->first_part, mm->last_part, flags,
 			part_act, NULL)) {
-		    tsk_errno = 0;
+		    tsk_error_reset();
 		}
 		mm->close(mm);
 	    }
 	    else {
 		/* Ignore error in this case and reset */
-		tsk_errno = 0;
+		tsk_error_reset();
 	    }
 	}
     }
