@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/04/07 21:21:03 $
+ * $Date: 2006/06/20 22:35:42 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -22,7 +22,7 @@
  * Return a buffer with a description of the partition type
  */
 static char *
-sun_get_desc(uint8_t fstype)
+sun_get_desc(uint16_t fstype)
 {
     char *str = mymalloc(64);
     if (str == NULL)
@@ -63,7 +63,7 @@ sun_get_desc(uint8_t fstype)
 	strncpy(str, "cachefs (0x0A)", 64);
 	break;
     default:
-	snprintf(str, 64, "Unknown Type (0x%.2x)", fstype);
+	snprintf(str, 64, "Unknown Type (0x%.4x)", fstype);
 	break;
     }
 
@@ -90,8 +90,8 @@ sun_load_table_i386(MM_INFO * mm, sun_dlabel_i386 * dlabel_x86)
 
 	if (verbose)
 	    fprintf(stderr,
-		"load_table_i386: %d  Starting Sector: %lu  Size: %lu  Type: %d\n",
-		idx,
+		"load_table_i386: %" PRIu32
+		"  Starting Sector: %lu  Size: %lu  Type: %d\n", idx,
 		(ULONG) getu32(mm, dlabel_x86->part[idx].start_sec),
 		(ULONG) getu32(mm, dlabel_x86->part[idx].size_sec),
 		getu16(mm, dlabel_x86->part[idx].type));
@@ -151,11 +151,10 @@ sun_load_table_sparc(MM_INFO * mm, sun_dlabel_sparc * dlabel_sp)
 
 	if (verbose)
 	    fprintf(stderr,
-		"load_table_sparc: %d  Starting Sector: %lu  Size: %lu  Type: %d\n",
-		idx,
-		(ULONG) part_start,
-		(ULONG) part_size,
-		getu16(mm, dlabel_sp->part_meta[idx].type));
+		"load_table_sparc: %" PRIu32
+		"  Starting Sector: %lu  Size: %lu  Type: %d\n", idx,
+		(ULONG) part_start, (ULONG) part_size, getu16(mm,
+		    dlabel_sp->part_meta[idx].type));
 
 	if (part_size == 0)
 	    continue;
@@ -308,7 +307,7 @@ sun_part_walk(MM_INFO * mm, PNUM_T start, PNUM_T last, int flags,
     if (start < mm->first_part || start > mm->last_part) {
 	tsk_errno = TSK_ERR_MM_WALK_RNG;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
-	    "sun_part_walk: Starting partition: %d", start);
+	    "sun_part_walk: Starting partition: %" PRIuPNUM, start);
 	tsk_errstr2[0] = '\0';
 	return 1;
     }
@@ -316,7 +315,7 @@ sun_part_walk(MM_INFO * mm, PNUM_T start, PNUM_T last, int flags,
     if (last < mm->first_part || last > mm->last_part) {
 	tsk_errno = TSK_ERR_MM_WALK_RNG;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
-	    "sun_part_walk: Ending partition: %d", last);
+	    "sun_part_walk: Ending partition: %" PRIuPNUM, last);
 	tsk_errstr2[0] = '\0';
 	return 1;
     }
